#!/usr/bin/env python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------------+
# |             ____ _               _        __  __ _  __           |
# |            / ___| |__   ___  ___| | __   |  \/  | |/ /           |
# |           | |   | '_ \ / _ \/ __| |/ /   | |\/| | ' /            |
# |           | |___| | | |  __/ (__|   <    | |  | | . \            |
# |            \____|_| |_|\___|\___|_|\_\___|_|  |_|_|\_\           |
# |                                                                  |
# | Copyright Mathias Kettner 2014             mk@mathias-kettner.de |
# +------------------------------------------------------------------+
#
# this file is part of mkp package "mikrotik"
# see package description and ~/local/share/doc/check_mk/mikrotik
# for details and maintainer
#
# check_mk is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# tails. You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

group = "datasource_programs"

register_rule(group,
    "special_agents:mikrotik",
    Dictionary(
        elements = [
            ( "user",
              TextAscii(
                  title = _("Username"),
                  allow_empty = False,
              )
            ),
            ( "password",
              Password(
                  title = _("Password"),
                  allow_empty = False,
              )
            ),
           ( "nossl",
              DropdownChoice(
                  title = _("Type of query"),
                  choices = [
                      ( False,             _("Use SSL (Default)" ) ),
                      ( True,              _("Do not use SSL to connect to API") ),
                  ],
                  default = False,
              )
            ),
            ( "connect",
              Integer(
                   title = _("TCP Port number"),
                   help = _("Port number for connection to API. Usually 8729 (SSL) "
                            "or 8728 (no SSL)"),
                   default_value = 8729,
                   minvalue = 1,
                   maxvalue = 65535,
              )
            ),
        ( "infos",
          Transform(
              ListChoice(
                 choices = [
                     ( "bgp",         _("BGP sessions") ),
                     ( "ospf",        _("OSPF Neighbors") ),
                     ( "vrrp",        _("VRRP info") ),
                     ( "health",      _("RouterOS Health") ),
                     ( "board",       _("RouterOS Board Info") ),
                     ( "ipsec",       _("IPsec") ),
                     ( "firewall",    _("Firewall rules") ),
                 ],
                 default_value = [ "bgp", "ospf", "health", "board", "vrrp", "ipsec", "firewall" ],
                 allow_empty = False,
               ),
               title = _("Retrieve information about..."),
            )
         ),

        ],
        optional_keys = False
    ),
    title = _("Check MikroTik RouterOS via API"),
    help = _("This rule activates an agent that collects information from "
             "MikroTik RouterOS API. Surprisingly this includes some switches."),
    match = 'first')

